TEST_DOMAIN = "https://dev-smartid.zonesmart.ru"
DOMAIN = "https://id.kokocgroup.ru"

AUTHORIZATION_URL = "{domain}"
TOKEN_ISSUE_URL = "{domain}/api/oauth2/issue/"
GET_USER_DATA_URL = "{domain}/api/user/auth_data/"

DEFAULT_SCOPE = "smart_id first_name last_name email phone roles"
